@@ -15,7 +15,7 @@ def sg_holiday_feature(holiday_df, startDate = '20200101', endDate = '20210101')
   df = date_pd.merge(holiday_df, on='DATE', how = 'left')
   df['Holiday'] = df['Holiday'].fillna('Non-Holiday')
   df = df[['DATE', 'Holiday']]
-  df_dummy = pd.get_dummies(df, columns = 'Holiday')
+  df_dummy = pd.get_dummies(df, columns = ['Holiday'])
   return df_dummy
 
 def get_dummy_value(df, dummy_columns):
